==> haskell-doctest-parallel-0.3.1-23-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-parallel
version:              0.3.1
visibility:           public
id:                   doctest-parallel-0.3.1-H8o1YidZU6l7DOB58CNYmL
key:                  doctest-parallel-0.3.1-H8o1YidZU6l7DOB58CNYmL
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  27cd09179466f62a391611741fd313ce
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Helpers Test.DocTest.Internal.Extract
    Test.DocTest.Internal.GhcUtil Test.DocTest.Internal.GhciWrapper
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Logging Test.DocTest.Internal.Nix
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:
    Control.Monad.Extra Data.List.Extra Paths_doctest_parallel

import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.3.1-H8o1YidZU6l7DOB58CNYmL
depends:
    Cabal-3.6.3.0 Glob-0.10.2-8UdYHIThKwJJhvo16hfruF base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd
    code-page-0.2.1-2Ge3Prwpi0K5qObDyqbdK0 containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.2 ghc-9.2.8 ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp
    process-1.6.16.0 random-1.2.1.2-16EsFile9CO8LN79UJ2fx
    syb-0.7.2.4-LOCaeanCkJLLhNbs0SZs6t transformers-0.5.6.2
    unordered-containers-0.2.20-FlJ58vN39MpAJvDCdrVy2C

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.3.1
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.3.1-LUazsgld6e0KP2jAR5iust-spectests-modules

key:
    doctest-parallel-0.3.1-LUazsgld6e0KP2jAR5iust-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  bf366b71d86e9845e0629462ff6a149f
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo GhcArg.Fib It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.3.1-LUazsgld6e0KP2jAR5iust-spectests-modules

depends:
    base-4.16.4.0 doctest-parallel-0.3.1-H8o1YidZU6l7DOB58CNYmL
    template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-doctest-parallel-0.3.1-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-doctest-parallel.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 doctest-parallel
version:              0.3.1
visibility:           public
id:                   doctest-parallel-0.3.1-AjY41UR0ZoxDHXEmgziKFn
key:                  doctest-parallel-0.3.1-AjY41UR0ZoxDHXEmgziKFn
license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  3121338a07375b0d889a9893a2d35c15
exposed:              True
exposed-modules:
    Test.DocTest Test.DocTest.Helpers Test.DocTest.Internal.Extract
    Test.DocTest.Internal.GhcUtil Test.DocTest.Internal.GhciWrapper
    Test.DocTest.Internal.Interpreter Test.DocTest.Internal.Location
    Test.DocTest.Internal.Logging Test.DocTest.Internal.Nix
    Test.DocTest.Internal.Options Test.DocTest.Internal.Parse
    Test.DocTest.Internal.Property Test.DocTest.Internal.Runner
    Test.DocTest.Internal.Runner.Example Test.DocTest.Internal.Util

hidden-modules:
    Control.Monad.Extra Data.List.Extra Paths_doctest_parallel

import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:         HSdoctest-parallel-0.3.1-AjY41UR0ZoxDHXEmgziKFn
depends:
    Cabal-3.6.3.0 Glob-0.10.2-BcJZTkVYAMPAVXEc7RmLJp base-4.16.4.0
    base-compat-0.12.2-5hQPtIjgG5LKnb20qwjRWd
    code-page-0.2.1-2Ge3Prwpi0K5qObDyqbdK0 containers-0.6.5.1
    deepseq-1.4.6.1 directory-1.3.6.2 exceptions-0.10.4
    filepath-1.4.2.2 ghc-9.2.8 ghc-paths-0.1.0.12-KU8OzVy7s6GithbR4F0cp
    process-1.6.16.0 random-1.2.1.2-F9rVStWFtZE3PBeMKQuK89
    syb-0.7.2.4-7ynUdJcB17N8mF8LpyS12V transformers-0.5.6.2
    unordered-containers-0.2.20-1oXBHIneMBm69TPTD2tYrr

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 z-doctest-parallel-z-spectests-modules
version:              0.3.1
package-name:         doctest-parallel
lib-name:             spectests-modules
id:
    doctest-parallel-0.3.1-HLSGGBS7Cls1NZOSxUAdl6-spectests-modules

key:
    doctest-parallel-0.3.1-HLSGGBS7Cls1NZOSxUAdl6-spectests-modules

license:              MIT
copyright:            (c) 2009-2018 Simon Hengel, 2021-2022 Martijn Bastiaan
maintainer:           Martijn Bastiaan <martijn@hmbastiaan.nl>
author:               Martijn Bastiaan <martijn@hmbastiaan.nl>
homepage:             https://github.com/martijnbastiaan/doctest-parallel#readme
synopsis:             Test interactive Haskell examples
description:
    The doctest program checks examples in source code comments.  It is modeled
    after doctest for Python (<https://docs.python.org/3/library/doctest.html>).

    Documentation is at <https://github.com/martijnbastiaan/doctest-parallel#readme>.

category:             Testing
abi:                  0bb5070c35df7382da14f925cde9cedb
exposed-modules:
    BugfixImportHierarchical.ModuleA BugfixImportHierarchical.ModuleB
    BugfixMultipleModules.ModuleA BugfixMultipleModules.ModuleB
    BugfixOutputToStdErr.Fib Color.Foo DosLineEndings.Fib Failing.Foo
    FailingMultiple.Foo GhcArg.Fib It.Foo It.Setup LocalStderrBinding.A
    ModuleIsolation.TestA ModuleIsolation.TestB ModuleOptions.Foo
    Multiline.Multiline NonExposedModule.Exposed PropertyBool.Foo
    PropertyBoolWithTypeSignature.Foo PropertyFailing.Foo
    PropertyImplicitlyQuantified.Foo PropertyQuantified.Foo
    PropertySetup.Foo Setup.Foo SetupSkipOnFailure.Foo
    SystemIoImported.A TemplateHaskell.Foo TestBlankline.Fib
    TestCombinedExample.Fib TestCommentLocation.Foo
    TestDocumentationForArguments.Fib TestFailOnMultiline.Fib
    TestImport.ModuleA TestImport.ModuleB TestPutStr.Fib TestSimple.Fib
    TrailingWhitespace.Foo WithCInclude.Bar WithCbits.Bar

hidden-modules:       NonExposedModule.NoImplicitImport
import-dirs:          /usr/lib/ghc-9.2.8/site-local/doctest-parallel-0.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/doctest-parallel-0.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-doctest-parallel
hs-libraries:
    HSdoctest-parallel-0.3.1-HLSGGBS7Cls1NZOSxUAdl6-spectests-modules

depends:
    base-4.16.4.0 doctest-parallel-0.3.1-AjY41UR0ZoxDHXEmgziKFn
    template-haskell-2.18.0.0

haddock-interfaces:
    /usr/share/doc/haskell-doctest-parallel/html/doctest-parallel.haddock

haddock-html:         /usr/share/doc/haskell-doctest-parallel/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
